-- 炼金工坊
Lua_AlchemyWindow = class("Lua_AlchemyWindow", Lua_Window);
function Lua_AlchemyWindow:ctor()
	self:superCall("ctor");
    
	self.windowName = "Lua_AlchemyWindow";
	self.skinName = "AlchemyWindow_skin";
	self.showBlackMask = true;
	self.isClickClose = true;
end

function Lua_AlchemyWindow:buildShowItem()
	self:superCall("buildShowItem");
	self.itemArr = Array();
	self.refreshTime = 0;

	self.itemList = Lua_DragList.new(self.content, 600, 350, Lua_AxisDefine.Horizontal);
	self.itemList:setLocation(0, 190, 0);
	self.itemList:setListCell(Lua_AlchemyItem, 200, 350, 1);

	self:addLuaEvent("UPDATE_SINGLE_ALCHEMY_INFO", self, self.updateSingleAlchemy);
	self:addLuaEvent("UPDATE_ALCHEMY_INFO", self, self.updateAlchemyInfo);
	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sAlchemyInfo();

	self.btnHelp:addClickFuntion(self, self.onHelpBtnClick);
end

function Lua_AlchemyWindow:dispose()
	self:endTimer();
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.itemArr ~= nil then
		self.itemArr:clear();
		self.itemArr = nil;
	end
	self.refreshTime = nil;
	self:superCall("dispose");
end

function Lua_AlchemyWindow:updateSingleAlchemy(msg)
	if msg == nil then
		return;
	end

	local len = self.itemArr:getSize()
	for i = 1, len do
		if self.itemArr[i].index == msg.alchemy_info.index then
			self.itemArr[i] = msg.alchemy_info;
			break;
		end
	end

	self:updateShowInfo();
end

function Lua_AlchemyWindow:updateAlchemyInfo(msg)
	self.itemArr:clear();

	if msg ~= nil then
		local list = msg.alchemy_list;
		for i = 1, #list do
			self.itemArr:add(list[i]);
		end
		self.refreshTime = msg.tick;
	end

	self:updateShowInfo();
end

function Lua_AlchemyWindow:updateShowInfo()
	self.itemList:setArrayData(self.itemArr);
	self:onTimer();
	self:startTimer();
end

function Lua_AlchemyWindow:startTimer()
	if self.bTiming == nil or self.bTiming == false then
		self.bTiming = true;
		self:addTimer("Lua_AlchemyWindow", 1, self, self.onTimer, nil, -1);
	end
end

function Lua_AlchemyWindow:endTimer()
	if self.bTiming ~= nil and self.bTiming == true then
		self.bTiming = false;
		self:removeTimer(self, self.onTimer);
	end
end

function Lua_AlchemyWindow:onTimer()
	local time = self.refreshTime - DataCenter.roleData.serverTime;
	if time <= 0 then
		self:endTimer();
		time = 0;
	end
	self.timeText.text = LanUtil.formateStr("刷新时间 : {1}", Lua_TimeTransform.transSeconds6(time));
end

function Lua_AlchemyWindow:onHelpBtnClick(go)
	local tipsData = { needAdapt = false, des = LanUtil.getValue(129002), posX = 80, posY = 462 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end




















Lua_AlchemyItem = class("Lua_AlchemyItem", Lua_ListCell);
function Lua_AlchemyItem:ctor(p)
	self:superCall("ctor", p, "AlchemyItem_skin");
end

function Lua_AlchemyItem:buildShowItem()
	self:superCall("buildShowItem");
	self.btnAlchemy:addClickFuntion(self, self.onAlchemyBtnClick);
end

function Lua_AlchemyItem:dispose()
	self.data = nil;
	self.configData = nil;
	self:superCall("dispose");
end

function Lua_AlchemyItem:setData(data)
	if data == nil then
		return;
	end
	self.data = data;
	self.configData = getConfig({ "alchemy", data.index });

	if self.configData == nil then
		self.incomeText.text = "";
	else
		self.incomeText.text = LanUtil.formateStr("挂机{1}小时收益", tostring(self.configData.profit / 60));
	end

	self.incomeCount.text = data.gold_profit.amount;
	self.leftTime.text = LanUtil.formateStr("剩余{1}次", tostring(data.left_times));
	if data.left_times > 0 then
		self.btnAlchemy:setEnable(true);
		self.alchemyImg:setEnable(false);

		if self.configData == nil then
			self.btnAlchemy.label = "";
		elseif self.configData.free == 1 then
			self.btnAlchemy.label = "免费";
		else
			self.btnAlchemy.label = spliceIconStrById(201000001)..self.configData.cost[2];
		end
	else
		self.btnAlchemy:setEnable(false);
		self.alchemyImg:setEnable(true);
	end
end

function Lua_AlchemyItem:onAlchemyBtnClick(go)
	if self.data == nil or self.configData == nil then
		return;
	end

	if self.configData.free ~= 1 then
		if not DataCenter.moneyData:isMoneyEnough(self.configData.cost[1], self.configData.cost[2], true, true) then
			return;
		end
	end

	Lua_ProxyManager.getProxy("Lua_RoleProxy"):sAlchemy(self.data.index);
end