-- 命格
Lua_RoleFatePanel = class("Lua_RoleFatePanel", Lua_DisplayObject);
function Lua_RoleFatePanel:ctor(p)
	self:superCall("ctor", p, "RoleFatePanel_skin");
end

function Lua_RoleFatePanel:buildShowItem()
	self:superCall("buildShowItem");
	self.chipArr = Array();

	self.redPoint = Lua_RedPointIcon.new(self.content, Lua_RedPointList.Fate);
	self.redPoint:setRectAnchor(7);

	if self.adaptHeight >= 0 then
		self.btnActivate:setLocation(0, 696);
		self.promptText:setLocation(0, 650);
		self.redPoint:setLocation(97, 720);
	else
		self.btnActivate:setLocation(0, 645.5);
		self.promptText:setLocation(0, 600);
		self.redPoint:setLocation(97, 660);
	end

    self.itemList = Lua_DragList.new(self.content, 700, 115, Lua_AxisDefine.Horizontal);
    self.itemList:setRectAnchor(7);
    self.itemList:setLocation(0, 530, 0);
    self.itemList:setListCell(Lua_RoleFateItem, 115, 115, 1);
    self.itemList:setCellSpacing(30, 0);
    
	self.attrList = Lua_DragList.new(self.content, 611, 174, Lua_AxisDefine.Vertical);
	self.attrList:setRectAnchor(7);
	self.attrList:setLocation(0, 300, 0);
	self.attrList:setListCell(Lua_RoleFateAttrItem, 611, 36, 1);
	self.attrList:setCellSpacing(0, 5);

	self:addLuaEvent("UPDATE_FATE_INFO", self, self.updateShowInfo);
	self:addLuaEvent("FATE_ITEM_SELECT", self, self.onFateItemSelect);
	if DataCenter.roleData.bInitFateData then
		self:updateShowInfo();
	else
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sFateInfo();
	end

	self.btnHelp:addClickFuntion(self, self.onHelpBtnClick);
	self.btnActivate:addClickFuntion(self, self.onActivateBtnClick);
end

function Lua_RoleFatePanel:dispose()
	Lua_CommonUtil.removeTimer(self, self.updateShow);
	if self.redPoint ~= nil then
		self.redPoint:dispose();
		self.redPoint = nil;
	end
	if self.fateArr ~= nil then
		self.fateArr:clear();
		self.fateArr = nil;
	end
	if self.costArr ~= nil then
		self.costArr:dispose();
		self.costArr:clear();
		self.costArr = nil;
	end
	if self.chipArr ~= nil then
		self.chipArr:dispose();
		self.chipArr:clear();
		self.chipArr = nil;
	end
	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	if self.rItem ~= nil then
		self.rItem:dispose();
		self.rItem = nil;
	end
	if self.attrList ~= nil then
		self.attrList:dispose();
		self.attrList = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_RoleFatePanel:onScreenResize(adaptHeight)
	self:superCall("onScreenResize", adaptHeight);
	if adaptHeight >= 0 then
		self.btnActivate:setLocation(0, 696);
		self.promptText:setLocation(0, 650);
		self.redPoint:setLocation(97, 720);
		if self.costArr then
			for i = 1, self.costArr:getSize() do
				self.costArr[i]:setLocation(posX, 650, 0);
			end
		end
	else
		self.btnActivate:setLocation(0, 645.5);
		self.promptText:setLocation(0, 600);
		self.redPoint:setLocation(97, 660);
		if self.costArr then
			for i = 1, self.costArr:getSize() do
				self.costArr[i]:setLocation(posX, 600, 0);
			end
		end
	end
end

function Lua_RoleFatePanel:updateShowInfo()
	local curFaceId = DataCenter.roleData.curFaceId;
	if self.data == nil then
		self:updateShow(curFaceId);
	else
		if self.curFaceId == curFaceId then
			self:onFateItemSelect(self.data);
		else
			self:updateChips(self.data);
			Lua_CommonUtil.delayCall(1, self, self.updateShow, curFaceId); -- 点亮最后一个碎片再刷新
		end
	end
	self:updateAttr();
	self.curFaceId = curFaceId;
end

function Lua_RoleFatePanel:updateShow(curFaceId)
	self.fateArr = DataCenter.roleUtil:getFateArr(curFaceId);
	self.itemList:setArrayData(self.fateArr);
	
	local index;
	for i = 1, self.fateArr:getSize() do
		if self.fateArr[i] == curFaceId then
			index = i;
			break;
		end
	end
	index = index == nil and 1 or index;
	self.itemList:moveToIndex(index - 2, true);
	self.itemList:setSelected(index);
	self.itemList:setSelectClick(index);
end

function Lua_RoleFatePanel:updateAttr()
	local curFaceId = DataCenter.roleData.curFaceId;
	local vo = DataCenter.roleUtil:getFateVoById(curFaceId);
	local chipId = vo.id * 100 + vo.level;
	local chipData = DataCenter.roleUtil:getFateChipConfig(chipId);
	local roleAttrDic = {};
	local heroAttrDic = {};
	DataCenter.attributesUtil:getAttrDic(chipData.leader_list, roleAttrDic);
	DataCenter.attributesUtil:getAttrDic(chipData.hero_list, heroAttrDic);
	local arr = Array();
	DataCenter.roleUtil:getAttrArr(roleAttrDic, 1, arr);
	DataCenter.roleUtil:getAttrArr(heroAttrDic, 2, arr);

	arr:sort("sortNum", false);
	self.attrList:setArrayData(arr);
	self.attrList.canDrag = not self.attrList.bDragEnd;
	
	arr:clear();
	arr = nil;
end

function Lua_RoleFatePanel:onFateItemSelect(data)
	self.data = data;
	local vo = DataCenter.roleUtil:getFateVoById(data.id);
	self.nameText.text = vo.name;

	local chipId;
	if vo.level >= #vo.chips then
		chipId = vo.id * 100 + #vo.chips;
	else
		chipId = vo.id * 100 + vo.level + 1;
	end
	self.chipData = DataCenter.roleUtil:getFateChipConfig(chipId);
	local bActivate = DataCenter.roleUtil:checkFateChipIsActivate(self.chipData.destiny_id, self.chipData.index);
	if bActivate then
		self.redPoint:setEnable(false);
		self.btnActivate:setMouseEnable(false);
		self.btnActivate:setStyle(16);
		self.btnActivate:setLangValue(350010);
		self.promptText:setEnable(false);
		self:showConsumeItem(nil);
	else
		self.redPoint:setEnable(true);
		self.btnActivate:setStyle(15);
		self.btnActivate:setLangValue(350009);

		if self.chipData.level > DataCenter.roleData.level then
			self.btnActivate:setMouseEnable(false);
			self.promptText:setEnable(true);
			self.promptText.text = LanUtil.formateStr(350011, tostring(self.chipData.level));
			self:showConsumeItem(nil);
		else
			self.btnActivate:setMouseEnable(true);
			self.promptText:setEnable(false);
			self:showConsumeItem(self.chipData.cost);
		end
	end

	self:updateChips(data);
end

function Lua_RoleFatePanel:showConsumeItem(data)
	if self.costArr == nil then
		self.costArr = Array();
	end

	local len = self.costArr:getSize();
	if data == nil then
		len = -len;
	else
		len = #data - len;
	end
	while (len > 0) do
		item = Lua_ConsumeIconItem.new(self.content);
		item.joinerStr = " / ";
		item:setStyle(Lua_MyUISettings.defaultFontName, 22, "FFFFFF", 2, "2B3136", 2, 2);
		item:setColorStr("2FC548", "FB524B");
		self.costArr:add(item);
		len = len - 1;
	end

	while (len < 0) do
		item = self.costArr:remove(1);
		item:dispose();
		len = len + 1;
	end

	len = self.costArr:getSize();
	local space = 300;
	local w = -(space * len) / 2 + space / 2;
	local posX;
	for i = 1, len do
		item = self.costArr[i];
		item:setData(data[i]);

		posX = ((i - 1) % len) * space + w;
		item:setRectAnchor(7);
		if self.adaptHeight >= 0 then
			item:setLocation(posX, 650, 0);
		else
			item:setLocation(posX, 600, 0);
		end
	end
end

function Lua_RoleFatePanel:updateChips(data)
	local posDic = {{-266, -514}, {-150, -250}, {153, -250}, {270, -514}, {0, -478}};
	local num = #data.chips;
	local len = self.chipArr:getSize();
	local maxLen = num > len and num or len;
	local item;
	for i = 1, maxLen do
		item = self.chipArr[i];
		if i > num then
			if item ~= nil then
				item:setEnable(false);
			end
		else
			if item == nil then
				item = Lua_RoleFateChipItem.new(self.content);
				self.chipArr:add(item);
			end
			item:setEnable(true);
			item:setRectAnchor(1);
			item:setLocation(posDic[i][1], posDic[i][2], 0);
			item:setFinal(i == num);
			item:setData(data.chips[i]);
		end
	end

	local chipId = data.chips[num];
	local configData = DataCenter.roleUtil:getFateChipConfig(chipId);
	local rewardConfig = Lua_RewardConfigData.getConfigDataById(configData.reward);
	if rewardConfig ~= nil then
		if self.rItem == nil then
			self.rItem = Lua_ItemIconList.new(self.content)
			self.rItem:setLocation(300, 0, 0);
			self.rItem.pivot = -1;
		end
		self.rItem:setArrayData(rewardConfig.rewardsArr);
	else
		if self.rItem ~= nil then
			self.rItem:setArrayData(nil);
		end
	end
end

function Lua_RoleFatePanel:onHelpBtnClick(go)
	local tipsData = { posX = 200, posY = -280, des = LanUtil.getValue(350006) };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_RoleFatePanel:onActivateBtnClick(go)
	if self.chipData == nil then
		return;
	end
	
	local costId, costCount = DataCenter.packData:checkConsumeEnough(self.chipData.cost);
	if costId == nil then
		Lua_ProxyManager.getProxy("Lua_RoleProxy"):sFateActivate();
	else
		DataCenter.packUtil:openPathWindow(costId, false);
	end
end




















Lua_RoleFateItem = class("Lua_RoleFateItem", Lua_ListCell);
function Lua_RoleFateItem:ctor(p)
	self:superCall("ctor", p, "RoleFateItem_skin");
end

function Lua_RoleFateItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RoleFateItem:dispose()
	self.data = nil;
	self:superCall("dispose");
end

function Lua_RoleFateItem:setData(data)
	self.data = DataCenter.roleUtil:getFateVoById(data);
	self.icon:setAltas("raccoon_atlas_1", self.data.iconSprite);
	self.name.text = self.data.name;

	local curFaceId = DataCenter.roleData.curFaceId;
	if self.data.id > curFaceId and self.data.is_activate == 0 then
		self.icon:setGray(true);
		self.name.colorStr = Lua_ColorDefine.transColorStr("D0D0D0");
		self:showLock(true);
	else
		self.icon:setGray(false);
		self.name.colorStr = Lua_ColorDefine.transColorStr("FFFFFF");
		self:showLock(false);
	end
end

function Lua_RoleFateItem:showLock(bShow)
	if bShow then
		if self.lockIcon == nil then
			self.lockIcon = UICreate.createUIAtlasImage(self.content, "common_altas_1", "ui_common_button_018_n", 0, 0, 0, 0);
			self.lockIcon:setScale(0.8, 0.8, 0.8);
		end
		self.lockIcon:setEnable(true);
	else
		if self.lockIcon ~= nil then
			self.lockIcon:setEnable(false);
		end
	end
end

function Lua_RoleFateItem:onSelectionChange(bSelect)
	self:superCall("onSelectionChange", bSelect);
	self.selectIcon:setEnable(bSelect);
end

function Lua_RoleFateItem:onPressClick()
	local curFaceId = DataCenter.roleData.curFaceId;
	if self.data.id > curFaceId and self.data.is_activate == 0 then
		OperateAlert.showLangValue(350012);
		return false;
	end

	Lua_MsgUtil.callFunc("FATE_ITEM_SELECT", self.data);
	return true;
end




















Lua_RoleFateAttrItem = class("Lua_RoleFateAttrItem", Lua_ListCell);
function Lua_RoleFateAttrItem:ctor(p)
	self:superCall("ctor", p, "RoleFateAttrItem_skin");
end

function Lua_RoleFateAttrItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RoleFateAttrItem:dispose()
	self:superCall("dispose");
end

function Lua_RoleFateAttrItem:setData(data)
	if data == nil then
		return;
	end

	self.attrIcon:setAltas("common_altas_2", data.icon);
	if data.attrType == 1 then
		self.nameText.text = LanUtil.formateStr(350007, data.name);
	elseif data.attrType == 2 then
		self.nameText.text = LanUtil.formateStr(350008, data.name);
	else
		self.nameText.text = data.name;
	end
	self.valueText.text = "+"..data.value;
end






















Lua_RoleFateChipItem = class("Lua_RoleFateChipItem", Lua_DisplayObject);
function Lua_RoleFateChipItem:ctor(p)
	self:superCall("ctor", p, "RoleFateChipItem_skin");
end

function Lua_RoleFateChipItem:buildShowItem()
	self:superCall("buildShowItem");
end

function Lua_RoleFateChipItem:dispose()
	self:superCall("dispose");
end

function Lua_RoleFateChipItem:setFinal(bFinal)
	self.bFinal = bFinal;
	if bFinal then
		self.attrText.fontSize = 28;
		self.attrText:setLocation(0, -77, 0);
	else
		self.attrText.fontSize = 22;
		self.attrText:setLocation(0, -50, 0);
	end
end

function Lua_RoleFateChipItem:setData(data)
	data = DataCenter.roleUtil:getFateChipConfig(data);
	if data == nil then
		return;
	end
	
	self.chipImg:setAltas("raccoon_atlas_1", data.icon_sprite);
	self.chipImg:resetSize();
	local bActivate = DataCenter.roleUtil:checkFateChipIsActivate(data.destiny_id, data.index);
	if bActivate then
		self.chipImg:setGray(false);
		self.attrText.colorStr = Lua_ColorDefine.transColorStr(data.color_str);
	else
		self.chipImg:setGray(true);
		self.attrText.colorStr = Lua_ColorDefine.transColorStr("B4B4B6");
	end	

	if data.leader ~= nil then
		local str = self:getAttrStr(bActivate, data.leader);
		self.attrText.text = LanUtil.formateStr(350007, str);
	elseif data.hero ~= nil then
		local str = self:getAttrStr(bActivate, data.hero);
		self.attrText.text = LanUtil.formateStr(350008, str);
	else
		self.attrText.text = "";
	end
end

function Lua_RoleFateChipItem:getAttrStr(bActivate, attr)
	local vo;
	local str;
	for k,v in pairs(attr) do
		if DataCenter.attributesUtil:isAtttribute(k) then
			vo = DataCenter.attributesUtil:createAttrVo(k);
			vo.value = v;
			if bActivate then
				if str == nil then
					str = LanUtil.formateStr(350031, vo.show_name, "FFFFFF", tostring(vo.showValue));
				else
					str = str.."<color=#FFFFFF>、</color>"..LanUtil.formateStr(350031, vo.show_name, "FFFFFF", tostring(vo.showValue));
				end
			else
				if str == nil then
					str = LanUtil.formateStr(350031, vo.show_name, "B4B4B6", tostring(vo.showValue));
				else
					str = str.."<color=#B4B4B6>、</color>"..LanUtil.formateStr(350031, vo.show_name, "B4B4B6", tostring(vo.showValue));
				end
			end
		end
	end
	return str;
end