checkRequire("Lua_PersonalAvatarItem")
Lua_PersonalInfoWindow = class("Lua_PersonalInfoWindow", Lua_Window)
function Lua_PersonalInfoWindow:ctor()
	self:superCall("ctor")

	self.windowName = "Lua_PersonalInfoWindow"
	self.skinName = "PersonalInfoWindow_skin"
	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER
	self.showBlackMask = true
	self.isClickClose = true
end

function Lua_PersonalInfoWindow:buildShowItem()
	self:superCall("buildShowItem")

	self.avatarItem = Lua_PersonalAvatarItem.new(self.content)
	self.avatarItem:setLocation(-182, 260, 0)

	self.forceNum = Lua_NumberImage.new(self.content)
	self.forceNum:setLocation(0, 216, 0)
	self.forceNum.pivot = 1
	self.forceNum.numOffsetX = -4
	self.forceNum.numAtlas = "number"
	self.forceNum.preStr = "xui_zl1_number_0"

	self.itemList = Lua_ItemIconList.new(self.content)
	self.itemList.canClick = true
	self.itemList:setLocation(0, -222.5, 0)

	self.redPointIcon = Lua_RedPointIcon.new(self.content, Lua_RedPointList.DressUp)
	self.redPointIcon:setLocation(-245, 335, 0)

	self.btnDressUp:addClickFuntion(self, self.onBtnDressUpClick)
	self.vipBg:addClickFuntion(self, self.onCheckVip)
	self.btnRename:addClickFuntion(self, self.onBtnRenameClick)
	self.btnFeedback:setEnable(false)
	self.btnFeedback:addClickFuntion(self, self.onBtnFeedbackClick)
	self.btnGiftCode:setEnable(false)
	self.btnGiftCode:addClickFuntion(self, self.onBtnGiftCodeClick)
	self.btnSetUp:setLocation(0, -380, 0)
	self.btnSetUp:addClickFuntion(self, self.onBtnSetUpClick)

	self:addLuaEvent("UPDATE_ROLE_INFO", self, self.updateShowInfo)
	self:addLuaEvent("UPDATE_DRESSUP_INFO", self, self.updateDressUpInfo)
	self:addLuaEvent("VIP_LEVEL_UPDATE", self, self.updateVipLvShowInfo)
	self:updateShowInfo()
	self:showLineUpInfo()
end

function Lua_PersonalInfoWindow:dispose()
	if self.avatarItem then
		self.avatarItem:dispose()
		self.avatarItem = nil
	end
	if self.forceNum then
		self.forceNum:dispose()
		self.forceNum = nil
	end
	if self.itemList then
		self.itemList:dispose()
		self.itemList = nil
	end
	if self.redPointIcon then
		self.redPointIcon:dispose()
		self.redPointIcon = nil
	end
	self:superCall("dispose")
end

function Lua_PersonalInfoWindow:updateShowInfo()
	local roleData = DataCenter.roleData
	self.vipText.text = roleData.vip
	self.nameText.text = roleData.name
	self.forceNum.num = roleData.force
	self.levelText.text = roleData.level
	self.roleIdText.text = roleData.roleId
	if roleData.league_id <= 0 then
		self.allianceText.text = LanUtil.getValue(20)
	else
		self.allianceText.text = roleData.league_name
	end

	local server_name = string.split(roleData.server_name, "#");
	self.serverText.text = server_name[2];

	self:updateDressUpInfo()
end

function Lua_PersonalInfoWindow:updateDressUpInfo()
	local roleData = DataCenter.roleData
	local avatarId = roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_HEAD)
	local frameId = roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_FRAME)
	local titleId = roleData:getOwnDressUpId(Lua_DressUpDefine.MAINTYPE_TITLE)

	self.avatarItem:setAvatar(avatarId)
	self.avatarItem:setRoleFrame(frameId)
	self.avatarItem:setRoleTitle(titleId)
end

function Lua_PersonalInfoWindow:updateVipLvShowInfo()
	self.vipText.text = DataCenter.vipData.level
end

function Lua_PersonalInfoWindow:showLineUpInfo()
	local lineupDic = DataCenter.heroLineupData:getServerLineupDic(Lua_HeroUtil.LINEUP_MAIN_TYPE);
	local arr = Array();
	local heroVo;
	for k, v in pairs(lineupDic[1]) do
		heroVo = DataCenter.heroData:getItemByUniqueId(v);
		arr:add(heroVo);
	end
	-- arr:sort("heroForce", true);
	self.itemList:setArrayData(arr);
end

function Lua_PersonalInfoWindow:onBtnDressUpClick(go)
	Lua_WindowUtil.openWin("Lua_DressUpWindow", Lua_WinParam.ACTION_OPEN, Lua_DressUpDefine.MAINTYPE_HEAD)
end

function Lua_PersonalInfoWindow:onCheckVip(go)
	DataCenter.funcPathUtil:gotoFunction(1034)
end

function Lua_PersonalInfoWindow:onBtnRenameClick(go)
	Lua_WindowUtil.openWin("Lua_RenameWindow", Lua_WinParam.ACTION_OPEN)
end

function Lua_PersonalInfoWindow:onBtnFeedbackClick(go)
	Lua_WindowUtil.openWin("Lua_FeedbackWindow", Lua_WinParam.ACTION_OPEN)
end

function Lua_PersonalInfoWindow:onBtnGiftCodeClick(go)
	Lua_WindowUtil.openWin("Lua_GiftCodeWindow", Lua_WinParam.ACTION_OPEN)
end

function Lua_PersonalInfoWindow:onBtnSetUpClick(go)
	Lua_WindowUtil.openWin("Lua_SetUpWindow", Lua_WinParam.ACTION_OPEN)
end